@@ -313,10 +313,7 @@ class TestMinisite(ImioSmartwebTestCase):
         html = viewlet.render()
         soup = BeautifulSoup(html)
         img = soup.find("img")
-        self.assertIn(
-            "background-image:url(http://nohost/plone/folder/@@images/",
-            img.get("src"),
-        )
+        self.assertIn("http://nohost/plone/folder/@@images/", img.get("src"))
 
         # Title should remain the same on sub-contents
         subfolder = api.content.create(
