@@ -14,8 +14,9 @@ export default function Events(props) {
         <Router>
             <EventsView
                 queryFilterUrl={props.queryFilterUrl}
-                queryUrl={props.queryUrl + "?b_size=20"}
+                queryUrl={props.queryUrl}
                 proposeUrl={props.proposeUrl}
+                batchSize={props.batchSize}
             />
         </Router>
     );
@@ -80,7 +81,7 @@ function EventsView(props) {
 
     // set batch
     const loadMore = () => {
-        setBatchStart((batchStart) => batchStart + 20);
+        setBatchStart((batchStart) => batchStart + props.batchSize);
         setLoadMoreLaunch(true);
     };
     // Update filters Batch
@@ -191,7 +192,7 @@ function EventsView(props) {
                             <div className="r-result r-annuaire-result">
                                 <div>{listRender}</div>
                                 <div className="r-load-more">
-                                    {contactNumber - 20 > batchStart ? (
+                                    {contactNumber - props.batchSize > batchStart ? (
                                         <button onClick={loadMore} className="btn-grad">
                                             {isLoading ? "Chargement..." : "Plus de résultats"}
                                         </button>
